PASTA-ELN Documentation
=======================

.. raw:: html

   <script src="https://cdn.jsdelivr.net/npm/lucide@latest/dist/umd/lucide.min.js"></script>
   <div class="three-columns">
      <div style="flex: 12;">
         <h2>PASTA-ELN | The favorite ELN<br>for experimental scientists</h2>
      </div>
      <div style="flex: 2;">
         <img src="_static/pasta_logo.svg" alt="logo" style="width: 100%;"/>
      </div>
   </div>

PASTA-ELN provides a streamlined and locally installed electronic labnotebook (ELN) for experimental scientists to efficiently organize raw data and associated metadata.

.. raw:: html

   <script src="https://cdn.jsdelivr.net/npm/lucide@latest/dist/umd/lucide.min.js"></script>
   <div class="three-columns">
      <div class="column">
         <div class="heading">Use cases</div>
         <a href="user_andrew.html" class="card">
            <div class="icon"><i data-lucide="square-chart-gantt"></i></div>
            <div class="text">Andrew <b>plans his research</b> and then executes the tasks ...</div>
         </a>
         <a href="user_brenda.html" class="card">
            <div class="icon"><i data-lucide="file-clock"></i></div>
            <div class="text">Brenda <b>imports data</b> from a previous research project ...</div>
         </a>
         <a href="user_claire.html" class="card">
            <div class="icon"><i data-lucide="presentation"></i></div>
            <div class="text">Claire <b>saves &amp; sorts notes</b> of conferences and meetings ...</div>
         </a>
      </div>
      <div class="column">
         <div class="heading">First steps</div>
         <a href="install.html" class="card">
            <div class="icon"><i data-lucide="settings"></i></div>
            <div class="text"><b>Installation</b> on your desktop computer</div>
         </a>
         <a href="addons.html" class="card">
            <div class="icon"><i data-lucide="blocks"></i></div>
            <div class="text"><b>Add-ons:</b> extractors, project reporter, etc.</div>
         </a>
         <a href="definitions.html" class="card">
            <div class="icon"><i data-lucide="database"></i></div>
            <div class="text">Configuration of<br> <b>data structure</b> and their <b>definitions</b></div>
         </a>
      </div>
      <div class="column">
         <div class="heading">More info</div>
         <a href="exchange.html" class="card">
            <div class="icon"><i data-lucide="arrow-right-left"></i></div>
            <div class="text">Data <b>interoperability</b> with other tools</div>
         </a>
         <a href="motivation.html" class="card">
            <div class="icon"><i data-lucide="lightbulb"></i></div>
            <div class="text"><b>Motivation</b> and <b>unique features</b> of PASTA-ELN</div>
         </a>
         <a href="develop.html" class="card">
            <div class="icon"><i data-lucide="square-code"></i></div>
            <div class="text">Guides for <b>contributors and developers</b></div>
         </a>
      </div>
   </div>
   <script src="https://cdn.jsdelivr.net/npm/lucide@latest/dist/umd/lucide.min.js"></script>
   <script>
   lucide.createIcons();
   </script>


.. toctree::
   :maxdepth: 1
   :hidden:

   user_andrew
   user_brenda
   user_claire
   install
   addons
   definitions
   exchange
   motivation
   develop
   developCode
   developInstall
